==> rendition-12.0.1.tgz: package/dist_esm5/components/DropDownButton/index.js <==
import { __assign, __extends, __makeTemplateObject, __rest } from "tslib";
import { faChevronDown } from '@fortawesome/free-solid-svg-icons/faChevronDown';
import { faChevronUp } from '@fortawesome/free-solid-svg-icons/faChevronUp';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import * as React from 'react';
import styled from 'styled-components';
import asRendition from '../../asRendition';
import { px } from '../../utils';
import { Box } from '../Box';
import Button from '../Button';
import Divider from '../Divider';
import Fixed from '../Fixed';
import { Flex } from '../Flex';
var TOGGLE_BUTTON_X_PADDING = 16;
var CHEVRON_ICON_WIDTH = 12;
var TOGGLE_BUTTON_WIDTH = 2 * TOGGLE_BUTTON_X_PADDING + CHEVRON_ICON_WIDTH;
var ToggleBase = styled(Button)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tmin-width: 0;\n\tborder-top-left-radius: 0;\n\tborder-bottom-left-radius: 0;\n\tborder-left: 0;\n\tmargin: 0;\n\tvertical-align: top;\n\tpadding: 0 ", ";\n\twidth: ", ";\n"], ["\n\tmin-width: 0;\n\tborder-top-left-radius: 0;\n\tborder-bottom-left-radius: 0;\n\tborder-left: 0;\n\tmargin: 0;\n\tvertical-align: top;\n\tpadding: 0 ", ";\n\twidth: ", ";\n"])), px(TOGGLE_BUTTON_X_PADDING), px(TOGGLE_BUTTON_WIDTH));
var ButtonBase = styled(Button)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tborder-top-right-radius: 0;\n\tborder-bottom-right-radius: 0;\n\tborder-right: 0;\n\tmargin: 0;\n\twidth: calc(100% - ", ");\n"], ["\n\tborder-top-right-radius: 0;\n\tborder-bottom-right-radius: 0;\n\tborder-right: 0;\n\tmargin: 0;\n\twidth: calc(100% - ", ");\n"])), px(TOGGLE_BUTTON_WIDTH));
var MenuBase = styled.div(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\tbackground: white;\n\tposition: absolute;\n\tmin-width: ", ";\n\tbox-shadow: ", ";\n\tborder-radius: ", ";\n\tborder: ", ";\n\tz-index: 1;\n\tmargin-top: 2px;\n\tleft: ", ";\n\tright: ", ";\n\twhite-space: nowrap;\n\tmax-height: ", ";\n\toverflow-y: auto;\n"], ["\n\tbackground: white;\n\tposition: absolute;\n\tmin-width: ", ";\n\tbox-shadow: ", ";\n\tborder-radius: ", ";\n\tborder: ", ";\n\tz-index: 1;\n\tmargin-top: 2px;\n\tleft: ", ";\n\tright: ", ";\n\twhite-space: nowrap;\n\tmax-height: ", ";\n\toverflow-y: auto;\n"])), function (props) { return props.minWidth; }, function (props) { return '1px 1px 5px' + props.theme.colors.gray.light; }, function (props) { return px(props.theme.radius); }, function (props) { return '1px solid ' + props.theme.colors.gray.main; }, function (props) { return (props.alignRight ? 'auto' : 0); }, function (props) { return (!props.alignRight ? 'auto' : 0); }, function (props) { return props.maxHeight || 'auto'; });
var Wrapper = styled(Box)(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n\tdisplay: inline-block;\n\tborder-radius: ", ";\n\tvertical-align: top;\n\tposition: relative;\n\n\tsvg {\n\t\twidth: ", ";\n\t\theight: translateY(1px);\n\t}\n"], ["\n\tdisplay: inline-block;\n\tborder-radius: ", ";\n\tvertical-align: top;\n\tposition: relative;\n\n\tsvg {\n\t\twidth: ", ";\n\t\theight: translateY(1px);\n\t}\n"])), function (props) { return px(props.theme.radius); }, px(CHEVRON_ICON_WIDTH));
var Item = styled.div(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n\tpadding: 4px 16px;\n\tborder-top: ", ";\n\tborder-radius: ", ";\n\n\t&:hover:enabled {\n\t\tbackground: ", ";\n\t}\n"], ["\n\tpadding: 4px 16px;\n\tborder-top: ",
    ";\n\tborder-radius: ", ";\n\n\t&:hover:enabled {\n\t\tbackground: ", ";\n\t}\n"])), function (props) {
    return props.border ? "1px solid " + props.theme.colors.gray.main : '0';
}, function (props) { return px(props.theme.radius); }, function (props) { return props.theme.colors.gray.light; });
var JoinedButton = styled(Button)(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n\tmargin: 0;\n\twidth: 100%;\n"], ["\n\tmargin: 0;\n\twidth: 100%;\n"])));
var Toggle = function (_a) {
    var open = _a.open, handler = _a.handler, label = _a.label, joined = _a.joined, props = __rest(_a, ["open", "handler", "label", "joined"]);
    if (joined) {
        if (label) {
            return (React.createElement(JoinedButton, __assign({}, props, { onClick: handler }),
                React.createElement(Flex, { justifyContent: "space-between", alignItems: "center" },
                    React.createElement(Box, { mr: 2 }, label),
                    open ? (React.createElement(FontAwesomeIcon, { icon: faChevronUp })) : (React.createElement(FontAwesomeIcon, { icon: faChevronDown })))));
        }
        return (React.createElement(JoinedButton, __assign({}, props, { icon: open ? (React.createElement(FontAwesomeIcon, { icon: faChevronUp })) : (React.createElement(FontAwesomeIcon, { icon: faChevronDown })), onClick: handler })));
    }
    return (React.createElement(ToggleBase, __assign({}, props, { icon: open ? (React.createElement(FontAwesomeIcon, { icon: faChevronUp })) : (React.createElement(FontAwesomeIcon, { icon: faChevronDown })), onClick: handler })));
};
var DropDownButton = (function (_super) {
    __extends(DropDownButton, _super);
    function DropDownButton(props) {
        var _this = _super.call(this, props) || this;
        _this.handleOutsideClick = function (e) {
            if (_this.dropdownNode && !_this.dropdownNode.contains(e.target)) {
                if (_this.state.open) {
                    _this.removeListener();
                    _this.setState({
                        open: false,
                    });
                }
            }
        };
        _this.toggle = function () {
            var isNextOpen = !_this.state.open;
            if (isNextOpen) {
                window.document.addEventListener('click', _this.handleOutsideClick);
            }
            else {
                _this.removeListener();
            }
            _this.setState({
                open: isNextOpen,
                minWidth: _this.base && _this.base.offsetWidth,
            });
        };
        _this.removeListener = function () {
            window.document.removeEventListener('click', _this.handleOutsideClick);
        };
        _this.state = {
            open: false,
            minWidth: 0,
        };
        return _this;
    }
    DropDownButton.prototype.componentWillUnmount = function () {
        if (this.state.open) {
            this.removeListener();
        }
    };
    DropDownButton.prototype.render = function () {
        var _this = this;
        var _a = this.props, alignRight = _a.alignRight, children = _a.children, label = _a.label, border = _a.border, joined = _a.joined, noListFormat = _a.noListFormat, outline = _a.outline, className = _a.className, props = __rest(_a, ["alignRight", "children", "label", "border", "joined", "noListFormat", "outline", "className"]);
        return (React.createElement(Wrapper, __assign({ className: className }, props, { ref: function (node) { return (_this.dropdownNode = node); } }),
            joined ? (React.createElement(Toggle, __assign({}, props, { outline: outline, joined: joined, label: label, handler: this.toggle, open: this.state.open }))) : (React.createElement("span", null,
                React.createElement(ButtonBase, __assign({}, props, { outline: outline }), label),
                React.createElement(Toggle, __assign({}, props, { outline: outline, handler: this.toggle, open: this.state.open })))),
            this.state.open && React.createElement(Fixed, { onClick: this.toggle }),
            this.state.open && (React.createElement(MenuBase, { alignRight: alignRight, onClick: this.toggle, minWidth: this.state.minWidth + "px", maxHeight: px(this.props.maxHeight) }, React.Children.map(children, function (child, i) {
                if (noListFormat) {
                    return child;
                }
                if (!child) {
                    return;
                }
                if (child.type === Divider) {
                    return child;
                }
                return (React.createElement(Item, { border: Boolean(border && i), key: i }, child));
            })))));
    };
    return DropDownButton;
}(React.Component));
export default asRendition(DropDownButton, [], ['color', 'bg', 'backgroundColor']);
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6;

==> rendition-13.0.0.tgz: package/dist_esm5/components/DropDownButton/index.js <==
import { __assign, __extends, __makeTemplateObject, __rest } from "tslib";
import { faChevronDown } from '@fortawesome/free-solid-svg-icons/faChevronDown';
import { faChevronUp } from '@fortawesome/free-solid-svg-icons/faChevronUp';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import * as React from 'react';
import styled from 'styled-components';
import asRendition from '../../asRendition';
import { px } from '../../utils';
import { Box } from '../Box';
import Button from '../Button';
import Divider from '../Divider';
import Fixed from '../Fixed';
import { Flex } from '../Flex';
var TOGGLE_BUTTON_X_PADDING = 16;
var CHEVRON_ICON_WIDTH = 12;
var TOGGLE_BUTTON_WIDTH = 2 * TOGGLE_BUTTON_X_PADDING + CHEVRON_ICON_WIDTH;
var ToggleBase = styled(Button)(templateObject_1 || (templateObject_1 = __makeTemplateObject(["\n\tmin-width: 0;\n\tborder-top-left-radius: 0;\n\tborder-bottom-left-radius: 0;\n\tborder-left: 0;\n\tmargin: 0;\n\tvertical-align: top;\n\tpadding: 0 ", ";\n\twidth: ", ";\n"], ["\n\tmin-width: 0;\n\tborder-top-left-radius: 0;\n\tborder-bottom-left-radius: 0;\n\tborder-left: 0;\n\tmargin: 0;\n\tvertical-align: top;\n\tpadding: 0 ", ";\n\twidth: ", ";\n"])), px(TOGGLE_BUTTON_X_PADDING), px(TOGGLE_BUTTON_WIDTH));
var ButtonBase = styled(Button)(templateObject_2 || (templateObject_2 = __makeTemplateObject(["\n\tborder-top-right-radius: 0;\n\tborder-bottom-right-radius: 0;\n\tborder-right: 0;\n\tmargin: 0;\n\twidth: calc(100% - ", ");\n"], ["\n\tborder-top-right-radius: 0;\n\tborder-bottom-right-radius: 0;\n\tborder-right: 0;\n\tmargin: 0;\n\twidth: calc(100% - ", ");\n"])), px(TOGGLE_BUTTON_WIDTH));
var MenuBase = styled(Box)(templateObject_3 || (templateObject_3 = __makeTemplateObject(["\n\tbackground: white;\n\tposition: absolute;\n\tbox-shadow: ", ";\n\tborder-radius: ", ";\n\tborder: ", ";\n\tz-index: 1;\n\tmargin-top: 2px;\n\tleft: ", ";\n\tright: ", ";\n\twhite-space: nowrap;\n\toverflow-y: auto;\n"], ["\n\tbackground: white;\n\tposition: absolute;\n\tbox-shadow: ", ";\n\tborder-radius: ", ";\n\tborder: ", ";\n\tz-index: 1;\n\tmargin-top: 2px;\n\tleft: ", ";\n\tright: ", ";\n\twhite-space: nowrap;\n\toverflow-y: auto;\n"])), function (props) { return '1px 1px 5px' + props.theme.colors.gray.light; }, function (props) { return px(props.theme.radius); }, function (props) { return '1px solid ' + props.theme.colors.gray.main; }, function (props) { return (props.alignRight ? 'auto' : 0); }, function (props) { return (!props.alignRight ? 'auto' : 0); });
var Wrapper = styled(Box)(templateObject_4 || (templateObject_4 = __makeTemplateObject(["\n\tdisplay: inline-block;\n\tborder-radius: ", ";\n\tvertical-align: top;\n\tposition: relative;\n\n\tsvg {\n\t\twidth: ", ";\n\t\theight: translateY(1px);\n\t}\n"], ["\n\tdisplay: inline-block;\n\tborder-radius: ", ";\n\tvertical-align: top;\n\tposition: relative;\n\n\tsvg {\n\t\twidth: ", ";\n\t\theight: translateY(1px);\n\t}\n"])), function (props) { return px(props.theme.radius); }, px(CHEVRON_ICON_WIDTH));
var Item = styled.div(templateObject_5 || (templateObject_5 = __makeTemplateObject(["\n\tpadding: 4px 16px;\n\tborder-top: ", ";\n\tborder-radius: ", ";\n\n\t&:hover:enabled {\n\t\tbackground: ", ";\n\t}\n"], ["\n\tpadding: 4px 16px;\n\tborder-top: ",
    ";\n\tborder-radius: ", ";\n\n\t&:hover:enabled {\n\t\tbackground: ", ";\n\t}\n"])), function (props) {
    return props.border ? "1px solid " + props.theme.colors.gray.main : '0';
}, function (props) { return px(props.theme.radius); }, function (props) { return props.theme.colors.gray.light; });
var JoinedButton = styled(Button)(templateObject_6 || (templateObject_6 = __makeTemplateObject(["\n\tmargin: 0;\n\twidth: 100%;\n"], ["\n\tmargin: 0;\n\twidth: 100%;\n"])));
var Toggle = function (_a) {
    var open = _a.open, handler = _a.handler, label = _a.label, joined = _a.joined, props = __rest(_a, ["open", "handler", "label", "joined"]);
    if (joined) {
        if (label) {
            return (React.createElement(JoinedButton, __assign({}, props, { onClick: handler }),
                React.createElement(Flex, { justifyContent: "space-between", alignItems: "center" },
                    React.createElement(Box, { mr: 2 }, label),
                    open ? (React.createElement(FontAwesomeIcon, { icon: faChevronUp })) : (React.createElement(FontAwesomeIcon, { icon: faChevronDown })))));
        }
        return (React.createElement(JoinedButton, __assign({}, props, { icon: open ? (React.createElement(FontAwesomeIcon, { icon: faChevronUp })) : (React.createElement(FontAwesomeIcon, { icon: faChevronDown })), onClick: handler })));
    }
    return (React.createElement(ToggleBase, __assign({}, props, { icon: open ? (React.createElement(FontAwesomeIcon, { icon: faChevronUp })) : (React.createElement(FontAwesomeIcon, { icon: faChevronDown })), onClick: handler })));
};
var DropDownButton = (function (_super) {
    __extends(DropDownButton, _super);
    function DropDownButton(props) {
        var _this = _super.call(this, props) || this;
        _this.handleOutsideClick = function (e) {
            if (_this.dropdownNode && !_this.dropdownNode.contains(e.target)) {
                if (_this.state.open) {
                    _this.removeListener();
                    _this.setState({
                        open: false,
                    });
                }
            }
        };
        _this.toggle = function () {
            var isNextOpen = !_this.state.open;
            if (isNextOpen) {
                window.document.addEventListener('click', _this.handleOutsideClick);
            }
            else {
                _this.removeListener();
            }
            _this.setState({
                open: isNextOpen,
                minWidth: _this.base && _this.base.offsetWidth,
            });
        };
        _this.removeListener = function () {
            window.document.removeEventListener('click', _this.handleOutsideClick);
        };
        _this.state = {
            open: false,
            minWidth: 0,
        };
        return _this;
    }
    DropDownButton.prototype.componentWillUnmount = function () {
        if (this.state.open) {
            this.removeListener();
        }
    };
    DropDownButton.prototype.render = function () {
        var _this = this;
        var _a = this.props, alignRight = _a.alignRight, children = _a.children, label = _a.label, border = _a.border, joined = _a.joined, noListFormat = _a.noListFormat, outline = _a.outline, className = _a.className, props = __rest(_a, ["alignRight", "children", "label", "border", "joined", "noListFormat", "outline", "className"]);
        return (React.createElement(Wrapper, __assign({ className: className }, props, { ref: function (node) { return (_this.dropdownNode = node); } }),
            joined ? (React.createElement(Toggle, __assign({}, props, { outline: outline, joined: joined, label: label, handler: this.toggle, open: this.state.open }))) : (React.createElement("span", null,
                React.createElement(ButtonBase, __assign({}, props, { outline: outline }), label),
                React.createElement(Toggle, __assign({}, props, { outline: outline, handler: this.toggle, open: this.state.open })))),
            this.state.open && React.createElement(Fixed, { onClick: this.toggle }),
            this.state.open && (React.createElement(MenuBase, { alignRight: alignRight, onClick: this.toggle, minWidth: this.state.minWidth + "px", maxHeight: px(this.props.listMaxHeight) }, React.Children.map(children, function (child, i) {
                if (noListFormat) {
                    return child;
                }
                if (!child) {
                    return;
                }
                if (child.type === Divider) {
                    return child;
                }
                return (React.createElement(Item, { border: Boolean(border && i), key: i }, child));
            })))));
    };
    return DropDownButton;
}(React.Component));
export default asRendition(DropDownButton, [], ['color', 'bg', 'backgroundColor']);
var templateObject_1, templateObject_2, templateObject_3, templateObject_4, templateObject_5, templateObject_6;
